'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mapStateToProps = exports.Issue = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _semanticUiReact = require('semantic-ui-react');

var _reactRedux = require('react-redux');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _utils = require('../../utils/utils');

var _utils2 = _interopRequireDefault(_utils);

require('./Issue.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var photo = {
  height: '70px',
  width: '70px'
};

function getDescription(assignedTo) {
  if (assignedTo[0] !== 'Not assigned') {
    return _react2.default.createElement(
      'div',
      { className: 'ui center aligned' },
      _react2.default.createElement(
        'div',
        null,
        _react2.default.createElement(
          _semanticUiReact.Header,
          { sub: true },
          'Assigned To: '
        ),
        assignedTo[0]
      ),
      _react2.default.createElement(_semanticUiReact.Item.Image, { style: photo, size: 'small', src: assignedTo[1] })
    );
  }
  return _react2.default.createElement('div', null);
}

var Issue = exports.Issue = function Issue(_ref) {
  var title = _ref.title,
      number = _ref.number,
      assignedTo = _ref.assignedTo,
      labels = _ref.labels;

  var styles = {
    borderTop: '0.25px solid black'
  };

  var readable = {
    fontSize: '16px'
  };

  var padRead = {
    fontSize: '16px',
    paddingTop: '10px'
  };

  var renderedLabels = labels.map(function (label) {
    return _react2.default.createElement(
      'div',
      { key: label },
      _react2.default.createElement(
        _semanticUiReact.Label,
        { className: 'ui medium label', ribbon: 'right', color: 'grey' },
        label
      )
    );
  });

  return _react2.default.createElement(
    _semanticUiReact.Card.Content,
    { style: styles },
    _react2.default.createElement(
      _semanticUiReact.List,
      { divided: true, relaxed: true },
      _react2.default.createElement(
        _semanticUiReact.List.Item,
        null,
        _react2.default.createElement(
          _semanticUiReact.List.Content,
          null,
          _react2.default.createElement(
            _semanticUiReact.List.Header,
            { style: readable },
            '#',
            number,
            ' ',
            title
          ),
          renderedLabels,
          _react2.default.createElement(
            _semanticUiReact.List.Description,
            { style: padRead },
            ' ',
            getDescription(assignedTo)
          )
        )
      )
    )
  );
};

Issue.propTypes = {
  title: _propTypes2.default.string.isRequired,
  number: _propTypes2.default.number.isRequired,
  assignedTo: _propTypes2.default.arrayOf(_propTypes2.default.string).isRequired,
  labels: _propTypes2.default.arrayOf(_propTypes2.default.string).isRequired
};

var mapStateToProps = exports.mapStateToProps = function mapStateToProps(state, ownProps) {
  var id = ownProps.widgetId;
  var issueId = ownProps.issueId;
  var issue = state.widgets.byId[id].issues.issuesById[issueId];
  var title = issue.title,
      number = issue.number,
      assignedTo = issue.assignedTo,
      labels = issue.labels;


  return {
    title: title,
    number: number,
    assignedTo: assignedTo,
    labels: labels
  };
};

exports.default = (0, _utils2.default)((0, _reactRedux.connect)(mapStateToProps)(Issue));